namespace Syntriax.Engine.Core.Abstract;

/// <summary>
/// Indicates the object is an <see cref="IAssignable"/> with an assignable <see cref="IEntity"/> field.
/// </summary>
public interface IAssignableEntity : IAssignable
{
    /// <summary>
    /// Event triggered when the <see cref="IEntity"/> value has has been assigned a new value.
    /// </summary>
    event OnEntityAssignedDelegate? OnEntityAssigned;

    /// <inheritdoc cref="IEntity" />
    IEntity Entity { get; }

    /// <summary>
    /// Assign a value to the <see cref="IEntity"/> field of this object.
    /// </summary>
    /// <param name="entity">New <see cref="IEntity"/> to assign.</param>
    /// <returns> 
    /// <see cref="true"/>, if the value given assigned successfully assigned, <see cref="false"/> if not.
    /// </returns>
    bool Assign(IEntity entity);

    delegate void OnEntityAssignedDelegate(IAssignableEntity sender);
}
